pub struct HealthCheck { /* private fields */ }Expand description
HealthCheck is used to represent a single check
Implementations
Sourceimpl HealthCheck
AggregatedStatus returns the “best” status for the list of health checks.
Because a given entry may have many service and node-level health checks
attached, this function determines the best representative of the status as
as single string using the following heuristic:
impl HealthCheck
AggregatedStatus returns the “best” status for the list of health checks. Because a given entry may have many service and node-level health checks attached, this function determines the best representative of the status as as single string using the following heuristic:
maintenance > critical > warning > passing
pub fn aggregated_status()